@@ -130,12 +130,12 @@ class Bucket {
     Bucket()
       : m_monsterBucketExtent(0)
       , m_available(0)
-      , m_data(0)
-      , m_mappedData(0)
-      , m_objectMap(0)
+      , m_data(nullptr)
+      , m_mappedData(nullptr)
+      , m_objectMap(nullptr)
       , m_largestFreeItem(0)
       , m_freeItemCount(0)
-      , m_nextBucketHash(0)
+      , m_nextBucketHash(nullptr)
       , m_dirty(false)
       , m_changed(false)
       , m_lastUsed(0)
@@ -214,7 +214,7 @@ class Bucket {
 
       if(static_cast<size_t>(file->pos()) != offset + (1+m_monsterBucketExtent)*DataSize)
       {
-        KMessageBox::error(0, i18n("Failed writing to %1, probably the disk is full", file->fileName()));
+        KMessageBox::error(nullptr, i18n("Failed writing to %1, probably the disk is full", file->fileName()));
         abort();
       }
 
@@ -461,11 +461,10 @@ class Bucket {
       return insertedAt;
     }
 
-    ///@param modulo Returns whether this bucket contains an item with (hash % modulo) == (item.hash % modulo)
-    ///              The default-parameter is the size of the next-bucket hash that is used by setNextBucketForHash and nextBucketForHash
-    ///@note modulo MUST be a multiple of ObjectMapSize, because (b-a) | (x * h1) => (b-a) | h2, where a|b means a is a multiple of b.
-    ///              This this allows efficiently computing the clashes using the local object map hash.
-
+    /// @param modulo Returns whether this bucket contains an item with (hash % modulo) == (item.hash % modulo)
+    ///               The default-parameter is the size of the next-bucket hash that is used by setNextBucketForHash and nextBucketForHash
+    /// @note modulo MUST be a multiple of ObjectMapSize, because (b-a) | (x * h1) => (b-a) | h2, where a|b means a is a multiple of b.
+    ///               This this allows efficiently computing the clashes using the local object map hash.
     bool hasClashingItem(uint hash, uint modulo) {
 
       Q_ASSERT(modulo % ObjectMapSize == 0);
@@ -922,9 +921,9 @@ class Bucket {
       ++m_freeItemCount;
     }
 
-    ///Returns true if the given index is right behind free space, and thus can be merged to the free space.
+    /// Returns true if the given index is right behind free space, and thus can be merged to the free space.
     bool isBehindFreeSpace(unsigned short index) const {
-      ///@todo Without iteration!
+      // TODO: Without iteration!
       unsigned short currentIndex = m_largestFreeItem;
 
       while(currentIndex) {
@@ -936,7 +935,7 @@ class Bucket {
       return false;
     }
 
-    ///@param index the index of an item @return The index of the next item in the chain of items with a same local hash, or zero
+    /// @param index the index of an item @return The index of the next item in the chain of items with a same local hash, or zero
     inline unsigned short followerIndex(unsigned short index) const {
       Q_ASSERT(index >= 2);
       return *reinterpret_cast<unsigned short*>(m_data+(index-2));
@@ -1013,7 +1012,7 @@ class DynamicItem {
     DynamicItem(const DynamicItem& rhs) : m_item(rhs.m_item), m_start(rhs.m_start) {
 //         qDebug() << "stealing" << m_item;
       Q_ASSERT(rhs.m_start);
-      rhs.m_start = 0;
+      rhs.m_start = nullptr;
     }
 
     Item* operator->() {
@@ -1057,20 +1056,20 @@ class ItemRepository : public AbstractItemRepository {
   ///                If this is zero, you have to care about storing the data using store() and/or close() by yourself. It does not happen automatically.
   ///                For the global standard registry, the storing/loading is triggered from within duchain, so you don't need to care about it.
   ItemRepository(const QString& repositoryName, ItemRepositoryRegistry* registry  = &globalItemRepositoryRegistry(),
-                 uint repositoryVersion = 1, AbstractRepositoryManager* manager = 0)
+                 uint repositoryVersion = 1, AbstractRepositoryManager* manager = nullptr)
     : m_ownMutex(QMutex::Recursive)
     , m_mutex(&m_ownMutex)
     , m_repositoryName(repositoryName)
     , m_registry(registry)
-    , m_file(0)
-    , m_dynamicFile(0)
+    , m_file(nullptr)
+    , m_dynamicFile(nullptr)
     , m_repositoryVersion(repositoryVersion)
     , m_manager(manager)
   {
     m_unloadingEnabled = true;
     m_metaDataChanged = true;
     m_buckets.resize(10);
-    m_buckets.fill(0);
+    m_buckets.fill(nullptr);
 
     memset(m_firstBucketForHash, 0, bucketHashSize * sizeof(short unsigned int));
 
@@ -1676,7 +1675,7 @@ class ItemRepository : public AbstractItemRepository {
 
   ///Synchronizes the state on disk to the one in memory, and does some memory-management.
   ///Should be called on a regular basis. Can be called centrally from the global item repository registry.
-  virtual void store() override {
+  void store() override {
     QMutexLocker lock(m_mutex);
     if(m_file) {
 
@@ -1694,7 +1693,7 @@ class ItemRepository : public AbstractItemRepository {
             const int unloadAfterTicks = 2;
             if(m_buckets[a]->lastUsed() > unloadAfterTicks) {
                 delete m_buckets[a];
-                m_buckets[a] = 0;
+                m_buckets[a] = nullptr;
             }else{
                 m_buckets[a]->tick();
             }
@@ -1748,7 +1747,7 @@ class ItemRepository : public AbstractItemRepository {
     m_mutex = mutex;
   }
 
-  virtual QString repositoryName() const override {
+  QString repositoryName() const override {
     return m_repositoryName;
   }
 
@@ -1899,7 +1898,7 @@ class ItemRepository : public AbstractItemRepository {
     return bucketPtr;
   }
 
-  virtual bool open(const QString& path) override {
+  bool open(const QString& path) override {
     QMutexLocker lock(m_mutex);
 
     close();
@@ -1909,9 +1908,9 @@ class ItemRepository : public AbstractItemRepository {
     m_dynamicFile = new QFile(dir.absoluteFilePath( m_repositoryName + QLatin1String("_dynamic") ));
     if(!m_file->open( QFile::ReadWrite ) || !m_dynamicFile->open( QFile::ReadWrite ) ) {
       delete m_file;
-      m_file = 0;
+      m_file = nullptr;
       delete m_dynamicFile;
-      m_dynamicFile = 0;
+      m_dynamicFile = nullptr;
       return false;
     }
 
@@ -1931,7 +1930,7 @@ class ItemRepository : public AbstractItemRepository {
       m_file->write((char*)&m_statItemCount, sizeof(uint));
 
       m_buckets.resize(10);
-      m_buckets.fill(0);
+      m_buckets.fill(nullptr);
       uint bucketCount = m_buckets.size();
       m_file->write((char*)&bucketCount, sizeof(uint));
 
@@ -1943,7 +1942,7 @@ class ItemRepository : public AbstractItemRepository {
       //We have completely initialized the file now
       if(m_file->pos() != BucketStartOffset)
       {
-        KMessageBox::error(0, i18n("Failed writing to %1, probably the disk is full", m_file->fileName()));
+        KMessageBox::error(nullptr, i18n("Failed writing to %1, probably the disk is full", m_file->fileName()));
         abort();
       }
 
@@ -1966,9 +1965,9 @@ class ItemRepository : public AbstractItemRepository {
       if(storedVersion != m_repositoryVersion || hashSize != bucketHashSize || itemRepositoryVersion != staticItemRepositoryVersion()) {
         qDebug() << "repository" << m_repositoryName << "version mismatch in" << m_file->fileName() << ", stored: version " << storedVersion << "hashsize" << hashSize << "repository-version" << itemRepositoryVersion << " current: version" << m_repositoryVersion << "hashsize" << bucketHashSize << "repository-version" << staticItemRepositoryVersion();
         delete m_file;
-        m_file = 0;
+        m_file = nullptr;
         delete m_dynamicFile;
-        m_dynamicFile = 0;
+        m_dynamicFile = nullptr;
         return false;
       }
       m_metaDataChanged = false;
@@ -1989,7 +1988,7 @@ class ItemRepository : public AbstractItemRepository {
     }
 
     m_fileMapSize = 0;
-    m_fileMap = 0;
+    m_fileMap = nullptr;
 
 #ifdef ITEMREPOSITORY_USE_MMAP_LOADING
     if(m_file->size() > BucketStartOffset){
@@ -2011,7 +2010,7 @@ class ItemRepository : public AbstractItemRepository {
   }
 
   ///@warning by default, this does not store the current state to disk.
-  virtual void close(bool doStore = false) override {
+  void close(bool doStore = false) override {
 
     if(doStore)
       store();
@@ -2019,14 +2018,14 @@ class ItemRepository : public AbstractItemRepository {
     if(m_file)
       m_file->close();
     delete m_file;
-    m_file = 0;
-    m_fileMap = 0;
+    m_file = nullptr;
+    m_fileMap = nullptr;
     m_fileMapSize = 0;
 
     if(m_dynamicFile)
       m_dynamicFile->close();
     delete m_dynamicFile;
-    m_dynamicFile = 0;
+    m_dynamicFile = nullptr;
 
     qDeleteAll(m_buckets);
     m_buckets.clear();
@@ -2065,7 +2064,7 @@ class ItemRepository : public AbstractItemRepository {
     return bucketPtr->visitAllItems(visitor);
   }
 
-  virtual int finalCleanup() override {
+  int finalCleanup() override {
     ThisLocker lock(m_mutex);
 
     int changed = 0;
@@ -2135,7 +2134,7 @@ class ItemRepository : public AbstractItemRepository {
     Q_ASSERT(bucketForIndex(bucketNumber)->isEmpty());
     Q_ASSERT(bucketForIndex(bucketNumber)->noNextBuckets());
     delete m_buckets[bucketNumber];
-    m_buckets[bucketNumber] = 0;
+    m_buckets[bucketNumber] = nullptr;
   }
 
   //m_file must be opened
@@ -2145,8 +2144,8 @@ class ItemRepository : public AbstractItemRepository {
     }
   }
 
-  ///Returns whether @param mustFindBucket was found
-  ///If mustFindBucket is zero, the whole chain is just walked. This is good for debugging for infinite recursion.
+  /// If mustFindBucket is zero, the whole chain is just walked. This is good for debugging for infinite recursion.
+  /// @return whether @p mustFindBucket was found
   bool walkBucketLinks(uint checkBucket, uint hash, uint mustFindBucket = 0) const {
     bool found = false;
     while(checkBucket) {
@@ -2158,9 +2157,9 @@ class ItemRepository : public AbstractItemRepository {
     return found || (mustFindBucket == 0);
   }
 
-  ///Computes the bucket where the chains opened by the buckets @param mainHead and @param intersectorHead
-  ///with hash @param hash meet each other.
-  ///@return <predecessor of first shared bucket in mainHead, first shared bucket>
+  /// Computes the bucket where the chains opened by the buckets @p mainHead and @p intersectorHead
+  /// with hash @p hash meet each other.
+  /// @return <predecessor of first shared bucket in mainHead, first shared bucket>
   QPair<unsigned int, unsigned int> hashChainIntersection(uint mainHead, uint intersectorHead, uint hash) const {
     uint previous = 0;
     uint current = mainHead;
